##  Using Collections
All users can view collections and the items included in them, unless access to specific items is restricted. To open a collection, select it from the left-side panel on the dashboards, reports, or diagrams page. Only non-empty collections are shown. You can navigate between different collections using the breadcrumbs menu at the top of the page.
![Navigating Between Collections](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274afd5c7a441014a522c3304d880f61_LowRes.gif)
Navigating Between Collections
Users with the permission to manage content within collections can do the following:
  * Add items: You can add an item to multiple collections.
  * Move items: Move items between different collections. Use this option to add items to subcollections. You can also drag and drop items to move them.
  * Remove items: Removing items from collections doesn’t delete any workspace data.


To perform these actions, click the three-dot icon on an item and use the corresponding options in the context menu.
![Context Menu Options for Collections on a Report](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274eb0557a441014aa2ebaf417fe9d76_LowRes.png)
Context Menu Options for Collections on a Report
